@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-crossref
 version: 0.2.0.0
-id: pandoc-crossref-0.2.0.0-08ff2a08213365b4646535c6eb2c582b
-key: pando_DfsP31vbD4cBQmJDAgXGB8
+id: pandoc-crossref-0.2.0.0-be034489b1216795aa0ab88755d79c02
+key: pando_1yyp1YGMjMN7M2gRkfLxgy
 license: GPL-2
 maintainer: root@livid.pp.ru
 synopsis: Pandoc filter for cross-references
@@ -32,7 +32,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-crossref-0.2.0.0
 data-dir: /usr/share/pandoc-crossref
-hs-libraries: HSpandoc-crossref-0.2.0.0-DfsP31vbD4cBQmJDAgXGB8
+hs-libraries: HSpandoc-crossref-0.2.0.0-1yyp1YGMjMN7M2gRkfLxgy
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -42,12 +42,12 @@ depends:
     data-accessor-transformers-0.2.1.7-082e9d05eabfdcb5b212785d058bd96b
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
-    pandoc-1.16.0.2-06729d26485fd2eeb4ea870c94353227
-    pandoc-types-1.16.1-74c09beb27b9195d9251808dae5f45b7
+    pandoc-1.16.0.2-1e3210a759893e8cb19c047605eb93fb
+    pandoc-types-1.16.1-4cd1533070797f7596c108f3982c26c4
     roman-numerals-0.5.1.5-e3bdc5830c32bed2d93467972766bc3b
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    yaml-0.8.16-9d8e48229c43339be2171b93f8cd276c
+    yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
 haddock-interfaces: /usr/share/doc/pandoc-crossref/html/pandoc-crossref.haddock
 haddock-html: /usr/share/doc/pandoc-crossref/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
